# References

---

## **Introduction**

User Facing Modules:

- generate_graph: Contains functions for creating new graphs e.g. A randomly growing list of graphs.
- prediction: Contains functions for predicting the next graph in a time-series list of graphs.
- utils: Contains helper functions, such as loading graphs from disk.

Internally used Modules:

- forecasting: Internal functions that assist in predictions.
- netseer: Used for running via CLI for testing

## **Prediction Module**

### :::src.netseer.prediction

---

## **Utils Module**

### :::src.netseer.utils

---

## **Generate Graph Module**

### :::src.netseer.generate_graph

---

## **Forecasting Module**

### :::src.netseer.forecasting

---

## **Netseer Module**

### :::src.netseer.netseer
